@@ -400,12 +400,6 @@ pof_future_ohl_cond_132_66_33kv <-
                      health_score_modifier$health_score_collar,
                      reliability_factor = reliability_factor)
 
-    # Probability of failure ---------------------------------------------------
-    probability_of_failure <- k *
-      (1 + (c * current_health_score) +
-         (((c * current_health_score)^2) / factorial(2)) +
-         (((c * current_health_score)^3) / factorial(3)))
-
     # Future probability of failure -------------------------------------------
 
     # the Health Score of a new asset
@@ -413,9 +407,8 @@ pof_future_ohl_cond_132_66_33kv <-
 
     # the Health Score of the asset when it reaches its Expected Life
     b2 <- beta_2(current_health_score, age)
-
     if (b2 > 2*b1){
-      b2 <- b1
+      b2 <- b1*2
     } else if (current_health_score == 0.5){
       b2 <- b1
     }
@@ -435,16 +428,16 @@ pof_future_ohl_cond_132_66_33kv <-
     for (y in 1:length(year)){
       t <- year[y]
 
-      future_health_Score <-
-        current_health_score*exp((b2/ageing_reduction_factor) * t)
+      future_health_Score <- current_health_score*exp((b2/ageing_reduction_factor) * t)
 
       H <- future_health_Score
 
       future_health_score_limit <- 15
       if (H > future_health_score_limit){
         H <- future_health_score_limit
+      } else if (H < 4) {
+        H <- 4
       }
-
       pof_year[[paste(y)]] <- k * (1 + (c * H) +
                                      (((c * H)^2) / factorial(2)) +
                                      (((c * H)^3) / factorial(3)))
