@@ -33,10 +33,6 @@
 #'oil_acidity = "Default",
 #'bd_strength = "Default",
 #'simulation_end_year = 100)
-# # Plot
-#'plot(future_pof_transformer$PoF * 100,
-#'type = "line", ylab = "%", xlab = "years",
-#'main = "PoF")
 
 pof_future_transformer_11_20kv <-
   function(hv_transformer_type = "6.6/11kV Transformer (GM)",
@@ -305,14 +301,14 @@ pof_future_transformer_11_20kv <-
          (((c * current_health_score)^3) / factorial(3)))
 
     # Future probability of failure -------------------------------------------
+
     # the Health Score of a new asset
     H_new <- 0.5
+
     # the Health Score of the asset when it reaches its Expected Life
-
     b2 <- beta_2(current_health_score, age)
-
     if (b2 > 2*b1){
-      b2 <- b1
+      b2 <- b1*2
     } else if (current_health_score == 0.5){
       b2 <- b1
     }
@@ -332,16 +328,16 @@ pof_future_transformer_11_20kv <-
     for (y in 1:length(year)){
       t <- year[y]
 
-      future_health_Score <-
-        current_health_score*exp((b2/ageing_reduction_factor) * t)
+      future_health_Score <- current_health_score*exp((b2/ageing_reduction_factor) * t)
 
       H <- future_health_Score
 
       future_health_score_limit <- 15
       if (H > future_health_score_limit){
         H <- future_health_score_limit
+      } else if (H < 4) {
+        H <- 4
       }
-
       pof_year[[paste(y)]] <- k * (1 + (c * H) +
                                      (((c * H)^2) / factorial(2)) +
                                      (((c * H)^3) / factorial(3)))
