@@ -4,13 +4,12 @@ library(CNAIM)
 context("Future Probability of Failure for a EHV submarine cable")
 
 test_that("pof_future_submarine_cables", {
-  # TODO: verify correctness
 
   res <- pof_future_submarine_cables(sub_cable_type = "EHV Sub Cable",
                                      utilisation_pct = 95,
                                      operating_voltage_pct = 80,
                                      topography = "High Detrimental Topography",
-                                     sitution = "Laid on bed",
+                                     situation = "Laid on bed",
                                      wind_wave = 3,
                                      intensity = "Low",
                                      landlocked = "no",
